==> haskell-async-2.1.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: async
version: 2.1.1
id: async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
key: async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
license: BSD3
copyright: (c) Simon Marlow 2012
maintainer: Simon Marlow <marlowsd@gmail.com>
homepage: https://github.com/simonmar/async
synopsis: Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.
    .
    Using @Async@ is safer than using threads in two
    ways:
    .
    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.
    .
    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').
category: Concurrency
author: Simon Marlow
exposed: True
exposed-modules:
    Control.Concurrent.Async
abi: 66f909bf795b33807a661fa462b1a90b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/async-2.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/async-2.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/async-2.1.1
hs-libraries: HSasync-2.1.1-9CmNvQft9hOA1w6AR7WdJM
depends:
    base-4.9.0.0 stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
haddock-interfaces: /usr/share/doc/haskell-async/html/async.haddock
haddock-html: /usr/share/doc/haskell-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-async-2.1.1.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: async
version: 2.1.1.1
id: async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4
key: async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4
license: BSD3
copyright: (c) Simon Marlow 2012
maintainer: Simon Marlow <marlowsd@gmail.com>
homepage: https://github.com/simonmar/async
synopsis: Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.
    .
    Using @Async@ is safer than using threads in two
    ways:
    .
    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.
    .
    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').
category: Concurrency
author: Simon Marlow
exposed: True
exposed-modules:
    Control.Concurrent.Async
abi: dfbc3cbd0439dc8c7d6c840c38546cb7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/async-2.1.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/async-2.1.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/async-2.1.1.1
hs-libraries: HSasync-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4
depends:
    base-4.9.0.0 stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
haddock-interfaces: /usr/share/doc/haskell-async/html/async.haddock
haddock-html: /usr/share/doc/haskell-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
